@@ -15,8 +15,8 @@
  * this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef VIEWMODE_H
-#define VIEWMODE_H
+#ifndef JUK_VIEWMODE_H
+#define JUK_VIEWMODE_H
 
 #include <QObject>
 #include <QStringList>
@@ -33,7 +33,7 @@ class ViewMode : public QObject
     Q_OBJECT
 
 public:
-    ViewMode(PlaylistBox *b);
+    explicit ViewMode(PlaylistBox *b);
     virtual ~ViewMode();
 
     virtual QString name() const;
@@ -81,7 +81,7 @@ protected:
     PlaylistBox *playlistBox() const { return m_playlistBox; }
     bool visible() const { return m_visible; }
     void setVisible(bool v) { m_visible = v; }
-    void updateIcons(int size);
+    void updateIcons();
     virtual void updateHeights();
     static void paintDropIndicator(QPainter *painter, int width, int height);
 
@@ -100,7 +100,7 @@ private:
 class CompactViewMode : public ViewMode
 {
 public:
-    CompactViewMode(PlaylistBox *b);
+    explicit CompactViewMode(PlaylistBox *b);
     virtual ~CompactViewMode();
 
     virtual QString name() const;
@@ -125,7 +125,7 @@ class TreeViewMode : public CompactViewMode
     Q_OBJECT
 
 public:
-    TreeViewMode(PlaylistBox *l);
+    explicit TreeViewMode(PlaylistBox *l);
     virtual ~TreeViewMode();
 
     virtual QString name() const;
